.. django-bleach documentation master file, created by
   sphinx-quickstart on Tue Jun 19 10:24:12 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

``django-bleach``
=======================

``bleach`` is a Python module that takes any HTML input, and returns valid,
sanitised HTML that contains only an allowed subset of HTML tags, attributes
and styles. ``django-bleach`` is a Django app that makes using bleach extremely
easy.

Contents:

.. toctree::
    :maxdepth: 2

    setup
    usage
    settings
